pub struct PermissionKey(String);Expand description
One validated dotted permission key.
Tuple Fields
0: StringImplementations
Sourceimpl PermissionKey
impl PermissionKey
Sourcepub fn parse(value: impl Into<String>) -> Result<Self, PermissionKeyError>
pub fn parse(value: impl Into<String>) -> Result<Self, PermissionKeyError>
Parses a dotted permission key with an optional trailing wildcard.
Errors
Returns an error for empty or invalid segments and misplaced wildcards.
Sourcepub fn from_segments(
segments: impl IntoIterator<Item = PermissionSegment>,
) -> Result<Self, PermissionKeyError>
pub fn from_segments( segments: impl IntoIterator<Item = PermissionSegment>, ) -> Result<Self, PermissionKeyError>
Builds a permission key from validated non-wildcard segments.
Errors
Returns an error when no segments are supplied.
Sourcepub fn child(
&self,
segment: &PermissionSegment,
) -> Result<Self, PermissionKeyError>
pub fn child( &self, segment: &PermissionSegment, ) -> Result<Self, PermissionKeyError>
pub(super) fn specificity(&self) -> usize
pub(super) fn scopes(&self, key: &Self) -> bool